==> generic-static-site-generator-1.0.4.tgz: package/README.md <==
# Generic Static Site Generator

![Generic Static Site Generator](https://theabbie.github.io/files/logo.png)

## Introduction

This is a Generic Static Site Generator, It is written in JavaScript, It can be used to create static websites

It is an organised and completely customisable Static Site Generator, It treats webpages as objects which can be evaluated.

This can be used to created all kinds of websites.

## Usage

```sh
gssg
```

## Contributing

Thank you for your interest in contributing, I would love to see your contributions, So, You could just create a PR, if it's really worth, I will merge it

## Help

Contact me anywhere, You can easily find me, Mail is preferable for formal communication, Instagram DM for small talks

## Installation

### Requirements

* Node.Js installed
* A website Architecture

### Installation

You have to install `GSSG` from NPM

```sh
npm install -g generic-static-site-generator
```

### Configuration

All the configuration data should be present in a `config.json` file

## Credits

Currently, I am the only one who can be credited for this, But, I was inspired by lack of a simple SSG, There are very cool ones, but somehow, I feel that they are unnecessarily complicated, My motive in this SSG is to make it ridiculously Simple

## Contact

[This](https://theabbie.github.io) is the gateway to my entire internet presence. Find me there. If that doesn't let you know enough about me, Then I am afraid to say, Nothing can

## License

This project is licensed under MIT License, See [LICENSE](/LICENSE) for more information

==> generic-static-site-generator-1.0.5.tgz: package/README.md <==
# Generic Static Site Generator

[![Join the chat at https://gitter.im/Generic-Static-Site-Generator/community](https://badges.gitter.im/Generic-Static-Site-Generator/community.svg)](https://gitter.im/Generic-Static-Site-Generator/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Rate on Openbase](https://badges.openbase.io/js/rating/generic-static-site-generator.svg)](https://openbase.io/js/generic-static-site-generator?utm_source=embedded&utm_medium=badge&utm_campaign=rate-badge)
[![StackShare](http://img.shields.io/badge/tech-stack-0690fa.svg?style=flat)](https://stackshare.io/generic-static-site-generator/generic-static-site-generator)

![Generic Static Site Generator](https://theabbie.github.io/files/logo.png)

## Introduction

This is a Generic Static Site Generator, It is written in JavaScript, It can be used to create static websites

It is an organised and completely customisable Static Site Generator, It treats webpages as objects which can be evaluated.

This can be used to created all kinds of websites.

## Usage

```sh
gssg
```

## Contributing

Thank you for your interest in contributing, I would love to see your contributions, So, You could just create a PR, if it's really worth, I will merge it

## Help

Contact me anywhere, You can easily find me, Mail is preferable for formal communication, Instagram DM for small talks

## Installation

### Requirements

* Node.Js installed
* A website Architecture

### Installation

You have to install `GSSG` from [NPM](https://www.npmjs.com/package/generic-static-site-generator)

```sh
npm install -g generic-static-site-generator
```

### Configuration

All the configuration data should be present in a `config.json` file

## Credits

Currently, I am the only one who can be credited for this, But, I was inspired by lack of a simple SSG, There are very cool ones, but somehow, I feel that they are unnecessarily complicated, My motive in this SSG is to make it ridiculously Simple

## Contact

[This](https://theabbie.github.io) is the gateway to my entire internet presence. Find me there. If that doesn't let you know enough about me, Then I am afraid to say, Nothing can

## License

This project is licensed under MIT License, See [LICENSE](/LICENSE) for more information
